@@ -361,13 +361,13 @@ class Cache(object):
           If set will make all numpy arrays read-only
         """
         self._id_function = id_function
-        # force stored numpy arrays to have flags.writable=False
+        # for stored numpy arrays set `flags.writable = False`
         self.force_immutable = bool(force_immutable)
         # call the id function for initial value
         self.id_current = self._id_function()
         # a counter for locks
         self._lock = 0
-        # actuSal store for data
+        # actual store for data
         self.cache = {}
 
     def delete(self, key):
@@ -426,7 +426,7 @@ class Cache(object):
         self.cache.update(items)
 
         if self.force_immutable:
-            for k, v in self.cache.items():
+            for v in self.cache.values():
                 if hasattr(v, 'flags') and len(v.shape) > 0:
                     v.flags.writeable = False
         self.id_set()
@@ -471,7 +471,8 @@ class Cache(object):
         # dumpy cache if ID function has changed
         self.verify()
         # make numpy arrays read-only if asked to
-        if self.force_immutable and hasattr(value, 'flags') and len(value.shape) > 0:
+        if self.force_immutable and hasattr(
+                value, 'flags') and len(value.shape) > 0:
             value.flags.writeable = False
         # assign data to dict
         self.cache[key] = value
@@ -607,8 +608,8 @@ class DataStore(Mapping):
         # make sure passed value is a bool
         is_mutable = bool(value)
         # apply the flag to any data stored
-        for n, i in self.data.items():
-            i.mutable = value
+        for v in self.data.values():
+            v.mutable = value
         # save the mutable setting
         self._mutable = is_mutable
 
