@@ -64,7 +64,7 @@ def export_mesh(mesh,
     # make sure file type is lower case
     file_type = str(file_type).lower()
 
-    if not (file_type in _mesh_exporters):
+    if file_type not in _mesh_exporters:
         raise ValueError('%s exporter not available!', file_type)
 
     if isinstance(mesh, (list, tuple, set, np.ndarray)):
@@ -223,6 +223,10 @@ def export_scene(scene,
     if len(scene.geometry) == 0:
         raise ValueError("Can't export empty scenes!")
 
+    if util.is_pathlib(file_obj):
+        # handle `pathlib` objects by converting to string
+        file_obj = str(file_obj.absolute())
+
     # if we weren't passed a file type extract from file_obj
     if file_type is None:
         if util.is_string(file_obj):
