@@ -446,7 +446,7 @@ class Path(parent.Geometry):
     @caching.cache_decorator
     def vertex_graph(self):
         """
-        Return a networkx.Graph object for the entity connectiviy
+        Return a networkx.Graph object for the entity connectivity
 
         graph : networkx.Graph
           Holds vertex indexes
@@ -1240,7 +1240,7 @@ class Path2D(Path):
         Parameters
         -------------
         **kwargs : dict
-          Passed to trimesh.creation.triangulate_polygon
+          Passed to `trimesh.creation.triangulate_polygon`
 
         Returns
         -------------
