@@ -478,7 +478,7 @@ class SceneGraph(object):
 
         # remove the geometry reference from the node without deleting nodes
         # this lets us keep our cached paths, and will not screw up children
-        for node, attrib in self.transforms.node_data.items():
+        for attrib in self.transforms.node_data.values():
             if 'geometry' in attrib and attrib['geometry'] in geometries:
                 attrib.pop('geometry')
 
@@ -600,7 +600,10 @@ class EnforcedForest(object):
         self._hash = None
 
         # delete all children's references and parent reference
-        children = [child for (child, parent) in self.parents.items() if parent == u]
+        children = [
+            child for (
+                child,
+                parent) in self.parents.items() if parent == u]
         for c in children:
             del self.parents[c]
         if u in self.parents:
